@@ -87,7 +87,7 @@ class PathVariable(UserDict[int, Path]):
     # not tested
     def append(self, path: Path):
         key = 1 + max(self.keys())
-        self.data[key] = Directory.from_path(path)
+        self.data[key] = Directory.from_path(str(path))
 
 
 @dataclass
@@ -221,7 +221,7 @@ def show(
                 get_comment(row) if comments else "",
             ]
             print(" ".join(item for item in items if item))
-    if color:
+    if color and not string:
         print(Style.RESET_ALL, end="")
 
 
